@@ -15,7 +15,7 @@
    (let ((persist--symbols nil)
          (sym (cl-gensym)))
      (persist-symbol sym 10)
-     (seq-contains persist--symbols sym))))
+     (seq-contains-p persist--symbols sym))))
 
 (ert-deftest test-persist-save-only-persistant ()
   ;; do not save not persist variables
@@ -134,3 +134,20 @@
         (should-error
          (persist-save 'fred)))
     (delete-directory "./persist-defined-location" t)))
+
+(ert-deftest test-persist-reset ()
+  "Symbol should be reset to a copy of the default."
+  (let ((initial-value (make-hash-table)))
+    (with-local-temp-persist
+     (persist-defvar persist--test-reset-variable initial-value "docstring")
+     (should-not (eq persist--test-reset-variable
+                     (persist-default 'persist--test-reset-variable)))
+     (should-not (eq persist--test-reset-variable initial-value))
+     (should-not (eq initial-value
+                     (persist-default 'persist--test-reset-variable)))
+     (persist-reset 'persist--test-reset-variable)
+     (should-not (eq persist--test-reset-variable
+                     (persist-default 'persist--test-reset-variable)))
+     (should-not (eq persist--test-reset-variable initial-value))
+     (should-not (eq initial-value
+                     (persist-default 'persist--test-reset-variable))))))
